@@ -25,7 +25,7 @@ __all__ = [
     "G24_SMCAvg",
     "G24_SMCBumps",
     "C25_M31Avg",
-    "G25_M33Avg",
+    "G26_M33Avg",
 ]
 
 
@@ -275,13 +275,19 @@ class B92_MWAvg(BaseExtModel):
          0.4999, 0.4708, 0.4496, 0.4395, 0.4192,
          0.4038, 0.3785, 0.36, 0.3493, 0.3402]
     )
-    obsdata_axav = np.array(
-        [0.849, 0.891, 0.941, 0.998, 1.045, 1.088,
-         1.139, 1.176, 1.226, 1.279, 1.34 , 1.418,
-         1.473, 1.507, 1.556, 1.595, 1.659, 1.718,
-         1.761, 1.795]
+    obsdata_Elm15_E22m15 = np.array(
+        [-0.327, -0.236, -0.128, -0.004, 0.098, 0.190,
+         0.301, 0.383, 0.491, 0.606, 0.738, 0.907,
+         1.027, 1.100, 1.206, 1.292, 1.431, 1.559,
+         1.651, 1.725]
     )
     # fmt: on
+    # determine values needed to convert to E(lambda-V)/E(B-V)
+    EVBm15_E22m15 = np.interp([1 / 0.55, 1 / 0.44], obsdata_x, obsdata_Elm15_E22m15)
+    obsdata_elvebv = (obsdata_Elm15_E22m15 - EVBm15_E22m15[0]) / (
+        EVBm15_E22m15[1] - EVBm15_E22m15[0]
+    )
+    obsdata_axav = obsdata_elvebv / Rv + 1.0
 
     # accuracy of the observed data based on published table
     obsdata_tolerance = 6e-3
@@ -1618,7 +1624,7 @@ class G24_SMCAvg(BaseExtModel):
         xo = 4.59
         gamma = 0.95
 
-        optnir_axav_x = 1.0 / np.array([2.198, 1.65, 1.25, 0.55, 0.44, 0.37])
+        optnir_axav_x = 1.0 / np.array([2.174, 1.622, 1.231, 0.544, 0.438, 0.363])
         optnir_axav_y = [0.062, 0.125, 0.324, 1.021, 1.349, 1.514]
 
         # return A(x)/A(V)
@@ -1750,7 +1756,7 @@ class G24_SMCBumps(BaseExtModel):
         xo = 4.73
         gamma = 1.15
 
-        optnir_axav_x = 1.0 / np.array([2.198, 1.65, 1.25, 0.55, 0.44, 0.37])
+        optnir_axav_x = 1.0 / np.array([2.174, 1.622, 1.231, 0.544, 0.438, 0.363])
         optnir_axav_y = [0.055, 0.162, 0.293, 1.017, 1.400, 1.684]
 
         # return A(x)/A(V)
@@ -1782,7 +1788,7 @@ class C25_M31Avg(BaseExtModel):
 
     Notes
     -----
-    From Clayton et al. (2025, ApJ, in press)
+    From Clayton et al. (2025, ApJ, 989, 61)
 
     One data point in the FUV from the data file giving the observed average was removed
     as it is *very* deviate from the FM90 parametrization.  This cause the automated tests
@@ -1902,9 +1908,9 @@ class C25_M31Avg(BaseExtModel):
         )
 
 
-class G25_M33Avg(BaseExtModel):
+class G26_M33Avg(BaseExtModel):
     r"""
-    Gordon et al (2025) M33 Average Extinction Curve
+    Gordon et al (2026) M33 Average Extinction Curve
 
     Parameters
     ----------
@@ -1916,7 +1922,7 @@ class G25_M33Avg(BaseExtModel):
 
     Notes
     -----
-    From Gordon et al. (2025, ApJ, submitted)
+    From Gordon et al. (2026, ApJ, submitted)
 
     Example showing the average curve
 
@@ -1927,17 +1933,17 @@ class G25_M33Avg(BaseExtModel):
         import matplotlib.pyplot as plt
         import astropy.units as u
 
-        from dust_extinction.averages import G25_M33Avg
+        from dust_extinction.averages import G26_M33Avg
 
         fig, ax = plt.subplots()
 
         # define the extinction model
-        ext_model = G25_M33Avg()
+        ext_model = G26_M33Avg()
 
         # generate the curves and plot them
         x = np.arange(ext_model.x_range[0], ext_model.x_range[1],0.1)/u.micron
 
-        ax.plot(x,ext_model(x),label='G25 M33 Average')
+        ax.plot(x,ext_model(x),label='G26 M33 Average')
         ax.plot(ext_model.obsdata_x, ext_model.obsdata_axav, 'ko',
                 label='obsdata')
 
@@ -1969,7 +1975,7 @@ class G25_M33Avg(BaseExtModel):
         with importlib_resources.as_file(ref) as data_path:
             # D22 sigma clipped average of 13 diffuse sightlines
             a = Table.read(
-                data_path / "G25_M33Ave.dat", format="ascii.commented_header"
+                data_path / "G26_M33Ave.dat", format="ascii.commented_header"
             )
 
         # data
@@ -1986,7 +1992,7 @@ class G25_M33Avg(BaseExtModel):
 
     def evaluate(self, x):
         """
-        G25 M33Avg function
+        G26 M33Avg function
 
         Parameters
         ----------
